@@ -4,9 +4,12 @@ Django admin declarations
 
 # Django
 from django.contrib import admin, messages
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext
 
 # AA SRP
-from aasrp.models import AaSrpLink, AaSrpRequest, AaSrpRequestComment, FleetType
+from aasrp.form import SettingAdminForm
+from aasrp.models import FleetType, RequestComment, Setting, SrpLink, SrpRequest
 
 
 def custom_filter(title):
@@ -18,30 +21,41 @@ def custom_filter(title):
 
     class Wrapper(admin.FieldListFilter):
         """
-        Custom_filter :: wrapper
+        Custom_filter wrapper
         """
 
         def expected_parameters(self):
             """
             Expected parameters
+
             :return:
             :rtype:
             """
 
-            pass
+            pass  # pylint: disable=unnecessary-pass
 
         def choices(self, changelist):
             """
             Choices
+
             :param changelist:
             :type changelist:
             :return:
             :rtype:
             """
 
-            pass
+            pass  # pylint: disable=unnecessary-pass
 
         def __new__(cls, *args, **kwargs):
+            """
+            New instance
+
+            :param args:
+            :type args:
+            :param kwargs:
+            :type kwargs:
+            """
+
             instance = admin.FieldListFilter.create(*args, **kwargs)
             instance.title = title
 
@@ -50,10 +64,62 @@ def custom_filter(title):
     return Wrapper
 
 
-@admin.register(AaSrpLink)
-class AaSrpLinkAdmin(admin.ModelAdmin):
+class SingletonModelAdmin(admin.ModelAdmin):
     """
-    AaSrpLinkAdmin
+    Prevents Django admin users deleting the singleton or adding extra rows.
+    """
+
+    actions = None  # Removes the default delete action.
+
+    def has_add_permission(self, request):  # pylint: disable=unused-argument
+        """
+        Has "add" permissions
+
+        :param request:
+        :type request:
+        :return:
+        :rtype:
+        """
+
+        return self.model.objects.all().count() == 0
+
+    def has_change_permission(
+        self, request, obj=None  # pylint: disable=unused-argument
+    ):
+        """
+        Has "change" permissions
+
+        :param request:
+        :type request:
+        :param obj:
+        :type obj:
+        :return:
+        :rtype:
+        """
+
+        return True
+
+    def has_delete_permission(
+        self, request, obj=None  # pylint: disable=unused-argument
+    ):
+        """
+        Has "delete" permissions
+
+        :param request:
+        :type request:
+        :param obj:
+        :type obj:
+        :return:
+        :rtype:
+        """
+
+        return False
+
+
+@admin.register(SrpLink)
+class SrpLinkAdmin(admin.ModelAdmin):
+    """
+    SrpLinkAdmin
     """
 
     list_display = (
@@ -71,19 +137,29 @@ class AaSrpLinkAdmin(admin.ModelAdmin):
     search_fields = ("srp_code", "fleet_doctrine", "srp_name")
 
     @classmethod
-    @admin.display(description="Creator", ordering="creator")
+    @admin.display(description=_("Creator"), ordering="creator")
     def _creator(cls, obj):
+        """
+        Display the creator name
+
+        :param obj:
+        :type obj:
+        :return:
+        :rtype:
+        """
+
         creator_name = obj.creator
+
         if obj.creator.profile.main_character:
             creator_name = obj.creator.profile.main_character.character_name
 
         return creator_name
 
 
-@admin.register(AaSrpRequest)
-class AaSrpRequestAdmin(admin.ModelAdmin):
+@admin.register(SrpRequest)
+class SrpRequestAdmin(admin.ModelAdmin):
     """
-    AaSrpRequestAdmin
+    SrpRequestAdmin
     """
 
     list_display = (
@@ -110,19 +186,29 @@ class AaSrpRequestAdmin(admin.ModelAdmin):
     )
 
     @classmethod
-    @admin.display(description="Creator", ordering="creator")
+    @admin.display(description=_("Requestor"), ordering="creator")
     def _creator(cls, obj):
+        """
+        Display the creator name
+
+        :param obj:
+        :type obj:
+        :return:
+        :rtype:
+        """
+
         creator_name = obj.creator
+
         if obj.creator.profile.main_character:
             creator_name = obj.creator.profile.main_character.character_name
 
         return creator_name
 
 
-@admin.register(AaSrpRequestComment)
-class AaSrpRequestCommentAdmin(admin.ModelAdmin):
+@admin.register(RequestComment)
+class RequestCommentAdmin(admin.ModelAdmin):
     """
-    AaSrpRequestCommentAdmin
+    RequestCommentAdmin
     """
 
     list_display = ("srp_request", "comment_type", "creator")
@@ -133,17 +219,18 @@ class AaSrpRequestCommentAdmin(admin.ModelAdmin):
 @admin.register(FleetType)
 class FleetTypeAdmin(admin.ModelAdmin):
     """
-    Config for fleet type model
+    FleetTypeAdmin
     """
 
     list_display = ("id", "_name", "_is_enabled")
     list_filter = ("is_enabled",)
     ordering = ("name",)
 
-    @admin.display(description="Fleet Type", ordering="name")
+    @admin.display(description=_("Fleet Type"), ordering="name")
     def _name(self, obj):
         """
         Rewrite name
+
         :param obj:
         :type obj:
         :return:
@@ -152,10 +239,11 @@ class FleetTypeAdmin(admin.ModelAdmin):
 
         return obj.name
 
-    @admin.display(description="Is Enabled", boolean=True, ordering="is_enabled")
+    @admin.display(description=_("Is enabled"), boolean=True, ordering="is_enabled")
     def _is_enabled(self, obj):
         """
         Rewrite is_enabled
+
         :param obj:
         :type obj:
         :return:
@@ -164,15 +252,13 @@ class FleetTypeAdmin(admin.ModelAdmin):
 
         return obj.is_enabled
 
-    actions = (
-        "activate",
-        "deactivate",
-    )
+    actions = ("activate", "deactivate")
 
-    @admin.action(description="Activate selected fleet type(s)")
+    @admin.action(description=_("Activate selected fleet types"))
     def activate(self, request, queryset):
         """
         Mark fleet type as active
+
         :param request:
         :type request:
         :param queryset:
@@ -190,19 +276,34 @@ class FleetTypeAdmin(admin.ModelAdmin):
                 obj.save()
 
                 notifications_count += 1
-            except Exception:
+            except Exception:  # pylint: disable=broad-exception-caught
                 failed += 1
 
         if failed:
-            messages.error(request, f"Failed to activate {failed} fleet types")
+            messages.error(
+                request=request,
+                message=ngettext(
+                    singular="Failed to activate {failed} fleet type",
+                    plural="Failed to activate {failed} fleet types",
+                    number=failed,
+                ).format(failed=failed),
+            )
 
         if queryset.count() - failed > 0:
-            messages.success(request, f"Activated {notifications_count} fleet type(s)")
+            messages.success(
+                request=request,
+                message=ngettext(
+                    singular="Activated {notifications_count} fleet type",
+                    plural="Activated {notifications_count} fleet types",
+                    number=notifications_count,
+                ).format(notifications_count=notifications_count),
+            )
 
-    @admin.action(description="Deactivate selected fleet type(s)")
+    @admin.action(description=_("Deactivate selected fleet types"))
     def deactivate(self, request, queryset):
         """
         Mark fleet type as inactive
+
         :param request:
         :type request:
         :param queryset:
@@ -220,13 +321,34 @@ class FleetTypeAdmin(admin.ModelAdmin):
                 obj.save()
 
                 notifications_count += 1
-            except Exception:
+            except Exception:  # pylint: disable=broad-exception-caught
                 failed += 1
 
         if failed:
-            messages.error(request, f"Failed to deactivate {failed} fleet types")
+            messages.error(
+                request=request,
+                message=ngettext(
+                    singular="Failed to deactivate {failed} fleet type",
+                    plural="Failed to deactivate {failed} fleet types",
+                    number=failed,
+                ).format(failed=failed),
+            )
 
         if queryset.count() - failed > 0:
             messages.success(
-                request, f"Deactivated {notifications_count} fleet type(s)"
+                request=request,
+                message=ngettext(
+                    singular="Deactivated {notifications_count} fleet type",
+                    plural="Deactivated {notifications_count} fleet types",
+                    number=notifications_count,
+                ).format(notifications_count=notifications_count),
             )
+
+
+@admin.register(Setting)
+class SettingAdmin(SingletonModelAdmin):
+    """
+    Setting Admin
+    """
+
+    form = SettingAdminForm
