@@ -4,6 +4,7 @@ App config
 
 # Django
 from django.apps import AppConfig
+from django.utils.translation import gettext_lazy as _
 
 # AA SRP
 from aasrp import __version__
@@ -16,4 +17,5 @@ class AaSrpConfig(AppConfig):
 
     name = "aasrp"
     label = "aasrp"
-    verbose_name = f"AA Ship Replacement v{__version__}"
+    # Translators: This is the app name and version, which will appear in the Django Backend
+    verbose_name = _(f"AA Ship Replacement v{__version__}")
