@@ -2,8 +2,6 @@
 Hook into AA
 """
 
-# Django
-from django.utils.translation import gettext_lazy as _
 
 # Alliance Auth
 from allianceauth import hooks
@@ -11,7 +9,7 @@ from allianceauth.services.hooks import MenuItemHook, UrlHook
 
 # AA SRP
 from aasrp import __title__, urls
-from aasrp.managers import AaSrpManager
+from aasrp.managers import SrpManager
 
 
 class AaSrpMenuItem(MenuItemHook):  # pylint: disable=too-few-public-methods
@@ -23,24 +21,27 @@ class AaSrpMenuItem(MenuItemHook):  # pylint: disable=too-few-public-methods
         # Setup menu entry for sidebar
         MenuItemHook.__init__(
             self,
-            _(__title__),
-            "far fa-money-bill-alt fa-fw",
-            "aasrp:dashboard",
+            text=__title__,
+            classes="far fa-money-bill-alt fa-fw",
+            url_name="aasrp:dashboard",
             navactive=["aasrp:"],
         )
 
     def render(self, request):
         """
         Check if the user has the permission to view this app
+
         :param request:
+        :type request:
         :return:
+        :rtype:
         """
 
         if request.user.has_perm("aasrp.basic_access"):
-            app_count = AaSrpManager.pending_requests_count_for_user(request.user)
+            app_count = SrpManager.pending_requests_count_for_user(request.user)
             self.count = app_count if app_count and app_count > 0 else None
 
-            return MenuItemHook.render(self, request)
+            return MenuItemHook.render(self, request=request)
 
         return ""
 
@@ -49,7 +50,9 @@ class AaSrpMenuItem(MenuItemHook):  # pylint: disable=too-few-public-methods
 def register_menu():
     """
     Register our menu item
+
     :return:
+    :rtype:
     """
 
     return AaSrpMenuItem()
@@ -59,7 +62,9 @@ def register_menu():
 def register_urls():
     """
     Register our base url
+
     :return:
+    :rtype:
     """
 
-    return UrlHook(urls, "aasrp", r"^ship-replacement/")
+    return UrlHook(urls=urls, namespace="aasrp", base_url=r"^ship-replacement/")
