@@ -20,13 +20,14 @@ from aasrp.constants import (
     ZKILLBOARD_BASE_URL_REGEX,
     ZKILLBOARD_KILLMAIL_URL_REGEX,
 )
-from aasrp.managers import AaSrpManager
-from aasrp.models import AaSrpLink, AaSrpRequest, AaSrpUserSettings, FleetType
+from aasrp.managers import SrpManager
+from aasrp.models import FleetType, Setting, SrpLink, SrpRequest, UserSetting
 
 
 def get_mandatory_form_label_text(text: str) -> str:
     """
     Label text for mandatory form fields
+
     :param text:
     :type text:
     :return:
@@ -43,17 +44,17 @@ def get_mandatory_form_label_text(text: str) -> str:
     )
 
 
-class AaSrpLinkForm(ModelForm):
+class SrpLinkForm(ModelForm):
     """
     New SRP lnk form
     """
 
     srp_name = forms.CharField(
-        required=True, label=get_mandatory_form_label_text(_("Fleet Name"))
+        required=True, label=get_mandatory_form_label_text(text=_("Fleet Name"))
     )
     fleet_time = forms.DateTimeField(
         required=True,
-        label=get_mandatory_form_label_text(_("Fleet Time")),
+        label=get_mandatory_form_label_text(text=_("Fleet Time")),
         widget=forms.DateTimeInput(attrs={"autocomplete": "off"}),
     )
     fleet_type = forms.ModelChoiceField(
@@ -63,22 +64,23 @@ class AaSrpLinkForm(ModelForm):
         # empty_label=_("Please select a fleet type"),
     )
     fleet_doctrine = forms.CharField(
-        required=True, label=get_mandatory_form_label_text(_("Fleet Doctrine"))
+        required=True,
+        label=get_mandatory_form_label_text(text=_("Doctrine")),
     )
-    aar_link = forms.CharField(required=False, label=_("AAR Link"))
+    aar_link = forms.CharField(required=False, label=_("After Action Report Link"))
 
     class Meta:  # pylint: disable=too-few-public-methods
         """
         Meta definitions
         """
 
-        model = AaSrpLink
+        model = SrpLink
         fields = ["srp_name", "fleet_time", "fleet_type", "fleet_doctrine", "aar_link"]
 
 
-class AaSrpLinkUpdateForm(ModelForm):
+class SrpLinkUpdateForm(ModelForm):
     """
-    Edit SRP link form
+    Edit SRP link update form
     """
 
     aar_link = forms.CharField(required=False, label=_("After Action Report Link"))
@@ -88,30 +90,29 @@ class AaSrpLinkUpdateForm(ModelForm):
         Meta definitions
         """
 
-        model = AaSrpLink
+        model = SrpLink
         fields = ["aar_link"]
 
 
-class AaSrpRequestForm(ModelForm):
+class SrpRequestForm(ModelForm):
     """
     SRP request form
     """
 
     killboard_link = forms.URLField(
-        label=get_mandatory_form_label_text(_("Killboard Link")),
+        label=get_mandatory_form_label_text(text=_("Killboard Link")),
         max_length=254,
         required=True,
-        help_text=(
-            f"Find your kill mail on {ZKILLBOARD_BASE_URL} "
-            f"or {EVETOOLS_KILLBOARD_BASE_URL} and paste the link here."
+        help_text=_(
+            f"Find your kill mail on {ZKILLBOARD_BASE_URL} or {EVETOOLS_KILLBOARD_BASE_URL} and paste the link here."  # pylint: disable=line-too-long
         ),
     )
 
     additional_info = forms.CharField(
         widget=forms.Textarea(attrs={"rows": 10, "cols": 20, "input_type": "textarea"}),
         required=True,
-        label=get_mandatory_form_label_text(_("Additional Info")),
-        help_text=(
+        label=get_mandatory_form_label_text(text=_("Additional Information")),
+        help_text=_(
             "Please tell us about the circumstances of your untimely demise. "
             "Who was the FC, what doctrine was called, have changes to the fit "
             "been requested and so on. Be as detailed as you can."
@@ -123,49 +124,50 @@ class AaSrpRequestForm(ModelForm):
         Meta definitions
         """
 
-        model = AaSrpRequest
+        model = SrpRequest
         fields = ["killboard_link", "additional_info"]
 
     def clean_killboard_link(self):
         """
         Check if it's a link from one of the accepted kill boards and clean it
+
         :return:
+        :rtype:
         """
 
         killboard_link = self.cleaned_data["killboard_link"]
 
         # Check if it's a link from one of the accepted kill boards
         if not any(
-            re.match(regex, killboard_link)
+            re.match(pattern=regex, string=killboard_link)
             for regex in [ZKILLBOARD_BASE_URL_REGEX, EVETOOLS_KILLBOARD_BASE_URL_REGEX]
         ):
             raise forms.ValidationError(
-                _(
-                    f"Invalid Link. Please use {ZKILLBOARD_BASE_URL} "
-                    f"or {EVETOOLS_KILLBOARD_BASE_URL}"
+                message=_(
+                    f"Invalid Link. Please use {ZKILLBOARD_BASE_URL} or {EVETOOLS_KILLBOARD_BASE_URL}"  # pylint: disable=line-too-long
                 )
             )
 
-        # Check if it's an actual kill mail
+        # Check if it's an actual killmail
         if not any(
-            re.match(regex, killboard_link)
+            re.match(pattern=regex, string=killboard_link)
             for regex in [
                 ZKILLBOARD_KILLMAIL_URL_REGEX,
                 EVETOOLS_KILLBOARD_KILLMAIL_URL_REGEX,
             ]
         ):
             raise forms.ValidationError(
-                _("Invalid link. Please post a link to a kill mail.")
+                message=_("Invalid link. Please post a link to a kill mail.")
             )
 
         # Check if there is already an SRP request for this kill mail
-        killmail_id = AaSrpManager.get_kill_id(killboard_link=killboard_link)
+        killmail_id = SrpManager.get_kill_id(killboard_link=killboard_link)
 
-        if AaSrpRequest.objects.filter(
+        if SrpRequest.objects.filter(
             killboard_link__icontains="/kill/" + killmail_id
         ).exists():
             raise forms.ValidationError(
-                _(
+                message=_(
                     "There is already an SRP request for this killmail. "
                     "Please check if you got the right one."
                 )
@@ -174,7 +176,7 @@ class AaSrpRequestForm(ModelForm):
         return killboard_link
 
 
-class AaSrpRequestPayoutForm(forms.Form):
+class SrpRequestPayoutForm(forms.Form):
     """
     Change payout value
     """
@@ -182,7 +184,7 @@ class AaSrpRequestPayoutForm(forms.Form):
     value = forms.CharField(label=_("SRP payout value"), max_length=254, required=True)
 
 
-class AaSrpRequestRejectForm(forms.Form):
+class SrpRequestRejectForm(forms.Form):
     """
     SRP request reject form
     """
@@ -190,14 +192,14 @@ class AaSrpRequestRejectForm(forms.Form):
     reject_info = forms.CharField(
         widget=forms.Textarea(attrs={"rows": 10, "cols": 20, "input_type": "textarea"}),
         required=True,
-        label=get_mandatory_form_label_text(_("Rejection Reason")),
+        label=get_mandatory_form_label_text(text=_("Reject Reason")),
         help_text=_("Please provide the reason this SRP request is rejected."),
     )
 
 
-class AaSrpRequestAcceptForm(forms.Form):
+class SrpRequestAcceptForm(forms.Form):
     """
-    SRP request reject form
+    SRP request accept form
     """
 
     reviser_comment = forms.CharField(
@@ -208,15 +210,15 @@ class AaSrpRequestAcceptForm(forms.Form):
     )
 
 
-class AaSrpRequestAcceptRejectedForm(forms.Form):
+class SrpRequestAcceptRejectedForm(forms.Form):
     """
-    SRP request reject form
+    SRP request accept rejected form
     """
 
     reviser_comment = forms.CharField(
         widget=forms.Textarea(attrs={"rows": 10, "cols": 20, "input_type": "textarea"}),
         required=True,
-        label=get_mandatory_form_label_text(_("Comment")),
+        label=get_mandatory_form_label_text(text=_("Comment")),
         help_text=_(
             "Please provide the reason why this former rejected SRP request is now "
             "accepted."
@@ -224,7 +226,7 @@ class AaSrpRequestAcceptRejectedForm(forms.Form):
     )
 
 
-class AaSrpUserSettingsForm(ModelForm):
+class UserSettingsForm(ModelForm):
     """
     User settings form
     """
@@ -243,5 +245,20 @@ class AaSrpUserSettingsForm(ModelForm):
         Meta definitions
         """
 
-        model = AaSrpUserSettings
+        model = UserSetting
         fields = ["disable_notifications"]
+
+
+class SettingAdminForm(forms.ModelForm):
+    """
+    Form definitions for the FleetType form in admin
+    """
+
+    class Meta:  # pylint: disable=too-few-public-methods
+        """
+        Meta
+        """
+
+        model = Setting
+        fields = "__all__"
+        widgets = {"default_embed_color": forms.TextInput(attrs={"type": "color"})}
