@@ -2,6 +2,9 @@
 Some helper functions, so we don't mess up other files too much
 """
 
+# Standard Library
+from typing import Optional
+
 # Django
 from django.contrib.auth.models import User
 from django.utils.translation import gettext_lazy as _
@@ -24,11 +27,19 @@ def get_formatted_character_name(
 ) -> str:
     """
     Get character name with alliance and corp ticker
+
     :param character:
+    :type character:
     :param with_portrait:
+    :type with_portrait:
     :param with_copy_icon:
+    :type with_copy_icon:
     :param portrait_size:
+    :type portrait_size:
     :param inline:
+    :type inline:
+    :return:
+    :rtype:
     """
 
     try:
@@ -41,90 +52,96 @@ def get_formatted_character_name(
             f"{character_name}"
             "</span>"
         )
-    else:
-        character__corporation_ticker = (
-            f"[{character.corporation_ticker}] " if character.corporation_ticker else ""
-        )
-        character__alliance_ticker = (
-            f"{character.alliance_ticker} " if character.alliance_ticker else ""
-        )
-        character_name_formatted = (
-            "<small class='text-muted'>"
-            f"{character__alliance_ticker}{character__corporation_ticker}</small>"
-            f"<br>{character_name}"
+
+    character__corporation_ticker = (
+        f"[{character.corporation_ticker}] " if character.corporation_ticker else ""
+    )
+    character__alliance_ticker = (
+        f"{character.alliance_ticker} " if character.alliance_ticker else ""
+    )
+    character_name_formatted = (
+        "<small class='text-muted'>"
+        f"{character__alliance_ticker}{character__corporation_ticker}</small>"
+        f"<br>{character_name}"
+    )
+
+    if with_copy_icon is True:
+        title = _("Copy character name to clipboard")
+        character_name_formatted += (
+            "<i "
+            'class="aa-srp-fa-icon aa-srp-fa-icon-right copy-text-fa-icon far fa-copy" '
+            f'data-clipboard-text="{character_name}" title="{title}"></i>'
         )
 
-        if with_copy_icon is True:
-            title = _("Copy character name to clipboard")
-            character_name_formatted += (
-                "<i "
-                'class="aa-srp-fa-icon aa-srp-fa-icon-right copy-text-fa-icon far fa-copy" '
-                f'data-clipboard-text="{character_name}" title="{title}"></i>'
-            )
+    return_value = character_name_formatted
 
-        return_value = character_name_formatted
+    if with_portrait is True:
+        line_break = ""
+        if inline is False:
+            line_break = "<br>"
 
-        if with_portrait is True:
-            line_break = ""
-            if inline is False:
-                line_break = "<br>"
+        character_portrait_html = get_character_portrait_from_evecharacter(
+            character=character, size=portrait_size, as_html=True
+        )
 
-            character_portrait_html = get_character_portrait_from_evecharacter(
-                character=character, size=portrait_size, as_html=True
-            )
-
-            return_value = (
-                f"{character_portrait_html}{line_break}"
-                "<span class='aasrp-character-portrait-character-name'>"
-                f"{character_name_formatted}"
-                "</span>"
-            )
+        return_value = (
+            f"{character_portrait_html}{line_break}"
+            "<span class='aasrp-character-portrait-character-name'>"
+            f"{character_name_formatted}"
+            "</span>"
+        )
 
     return return_value
 
 
-def get_main_for_character(character: EveCharacter) -> EveCharacter:
+def get_main_for_character(character: EveCharacter) -> Optional[EveCharacter]:
     """
     Get the main character for a given eve character
+
     :param character:
+    :type character:
+    :return:
+    :rtype:
     """
 
     try:
         userprofile = character.character_ownership.user.profile
     except (
+        AttributeError,
         EveCharacter.character_ownership.RelatedObjectDoesNotExist,
         CharacterOwnership.user.RelatedObjectDoesNotExist,
     ):
-        return_value = None
-    else:
-        return_value = userprofile.main_character
+        return None
 
-    return return_value
+    return userprofile.main_character
 
 
 def get_user_for_character(character: EveCharacter) -> User:
     """
     Get the user for a character
+
     :param character:
+    :type character:
     :return:
+    :rtype:
     """
 
     try:
         userprofile = character.character_ownership.user.profile
     except (
+        AttributeError,
         EveCharacter.character_ownership.RelatedObjectDoesNotExist,
         CharacterOwnership.user.RelatedObjectDoesNotExist,
     ):
-        return_value = get_sentinel_user()
-    else:
-        return_value = userprofile.user
+        return get_sentinel_user()
 
-    return return_value
+    return userprofile.user
 
 
 def get_main_character_from_user(user: User) -> str:
     """
     Get the main character from a user
+
     :param user:
     :type user:
     :return:
