@@ -11,10 +11,10 @@ from django.core.management.base import BaseCommand
 
 # Alliance Auth (External Libs)
 from app_utils.logging import LoggerAddTag
+from eveuniverse.constants import EveCategoryId
 
 # AA SRP
 from aasrp import __title__
-from aasrp.constants import EVE_CATEGORY_ID_SHIP
 
 logger = LoggerAddTag(logging.getLogger(__name__), __title__)
 
@@ -27,6 +27,14 @@ class Command(BaseCommand):
     help = "Preloads data required for this app from ESI"
 
     def add_arguments(self, parser):
+        """
+        Add argument to parser
+        :param parser:
+        :type parser:
+        :return:
+        :rtype:
+        """
+
         parser.add_argument(
             "--noinput",
             "--no-input",
@@ -34,18 +42,23 @@ class Command(BaseCommand):
             help="Do NOT prompt the user for input of any kind.",
         )
 
-    def handle(self, *args, **options):
+    def handle(self, *args, **options):  # pylint: disable=unused-argument
         """
         Start the eve type import
+
         :param args:
+        :type args:
         :param options:
+        :type options:
+        :return:
+        :rtype:
         """
 
         params = [
             "eveuniverse_load_types",
             __title__,
             "--category_id",
-            str(EVE_CATEGORY_ID_SHIP),
+            str(EveCategoryId.SHIP.value),
         ]
 
         if options["noinput"]:
