@@ -14,8 +14,8 @@ from eveuniverse.models import EveType
 
 # AA SRP
 from aasrp.helper.character import get_user_for_character
-from aasrp.managers import AaSrpManager
-from aasrp.models import AaSrpLink, AaSrpRequest, AaSrpRequestComment
+from aasrp.managers import SrpManager
+from aasrp.models import RequestComment, SrpLink, SrpRequest
 
 
 def get_input(text):
@@ -27,12 +27,20 @@ def get_input(text):
 
 
 class Command(BaseCommand):
-    help = "Migrate srp data from the built-in SRP module"
+    """
+    Migrate SRP data from the built-in SRP module
+    """
 
-    def _migrate_srp_data(self) -> None:
+    help = "Migrate SRP data from the built-in SRP module"
+
+    def _migrate_srp_data(  # pylint: disable=too-many-locals, too-many-statements
+        self,
+    ) -> None:
         """
         Migrate srp data from the built-in SRP module
+
         :return:
+        :rtype:
         """
 
         srp_links_migrated = 0
@@ -60,28 +68,28 @@ class Command(BaseCommand):
                 srp_fleet_aar_link = srp_fleet.fleet_srp_aar_link
 
                 # Fix srp status
-                srp_fleet_status = AaSrpLink.Status.ACTIVE
+                srp_fleet_status = SrpLink.Status.ACTIVE
                 if srp_fleet.fleet_srp_status == "Completed":
-                    srp_fleet_status = AaSrpLink.Status.COMPLETED
+                    srp_fleet_status = SrpLink.Status.COMPLETED
 
                 if srp_fleet.fleet_srp_code == "":
-                    srp_fleet_status = AaSrpLink.Status.CLOSED
+                    srp_fleet_status = SrpLink.Status.CLOSED
 
                     # Also fix the missing SRP code, we need it!
                     srp_fleet.fleet_srp_code = get_random_string(
-                        length=8
-                    )  # 8 chars only because old SRP link
+                        length=8  # 8 chars only because it's an old SRP link
+                    )
 
                 srp_fleet_srp_code = srp_fleet.fleet_srp_code
 
-                self.stdout.write(f"Migrating SRP fleet {srp_fleet_srp_code} ...")
+                self.stdout.write(f"Migrating SRP fleet {srp_fleet_srp_code} …")
 
                 try:
-                    srp_link = AaSrpLink.objects.get(srp_code=srp_fleet_srp_code)
+                    srp_link = SrpLink.objects.get(srp_code=srp_fleet_srp_code)
 
                     srp_links_skipped += 1
-                except AaSrpLink.DoesNotExist:
-                    srp_link = AaSrpLink()
+                except SrpLink.DoesNotExist:
+                    srp_link = SrpLink()
 
                     srp_link.srp_name = srp_fleet_name
                     srp_link.srp_status = srp_fleet_status
@@ -93,14 +101,14 @@ class Command(BaseCommand):
                     srp_link.creator = srp_fleet_creator
                     srp_link.save()
 
-                    # Mark migrated SRP link as COMPLETED and save the object
+                    # Mark migrated the SRP link as COMPLETED and save the object
                     srp_fleet.fleet_srp_status = "Completed"
                     srp_fleet.save()
 
                     srp_links_migrated += 1
 
                     # get the new srp link object
-                    srp_link = AaSrpLink.objects.get(srp_code=srp_fleet_srp_code)
+                    srp_link = SrpLink.objects.get(srp_code=srp_fleet_srp_code)
 
                 self.stdout.write(
                     f"Migrating SRP requests for SRP fleet {srp_fleet_srp_code} ..."
@@ -109,23 +117,26 @@ class Command(BaseCommand):
 
                 for srp_userrequest in srp_userrequests:
                     # Let's see if the creator is still valid
-                    # Returns None when the creators account has been deleted
+                    # Returns None when the creators' account has been deleted
                     # and no sentinel user can be created or obtained
                     # in this case, we cannot create the request again
                     srp_userrequest_creator = get_user_for_character(
                         character=srp_userrequest.character
                     )
 
-                    if srp_userrequest_creator is not None:
+                    if (
+                        srp_userrequest_creator is not None
+                        and srp_userrequest.character is not None
+                    ):
                         srp_userrequest_killboard_link = srp_userrequest.killboard_link
 
                         try:
-                            AaSrpRequest.objects.get(
+                            SrpRequest.objects.get(
                                 killboard_link=srp_userrequest_killboard_link
                             )
 
                             srp_requests_skipped += 1
-                        except AaSrpRequest.DoesNotExist:
+                        except SrpRequest.DoesNotExist:
                             srp_userrequest_additional_info = (
                                 srp_userrequest.additional_info
                             )
@@ -137,19 +148,19 @@ class Command(BaseCommand):
                                     name=srp_userrequest.srp_ship_name
                                 )
                             except EveType.DoesNotExist:
-                                srp_kill_link = AaSrpManager.get_kill_id(
+                                srp_kill_link = SrpManager.get_kill_id(
                                     srp_userrequest_killboard_link
                                 )
 
                                 (
                                     ship_type_id,
-                                    ship_value,
-                                    victim_id,
-                                ) = AaSrpManager.get_kill_data(srp_kill_link)
+                                    ship_value,  # pylint: disable=unused-variable
+                                    victim_id,  # pylint: disable=unused-variable
+                                ) = SrpManager.get_kill_data(srp_kill_link)
 
                                 (
                                     srp_userrequest_ship,
-                                    created_from_esi,
+                                    created_from_esi,  # pylint: disable=unused-variable
                                 ) = EveType.objects.get_or_create_esi(id=ship_type_id)
 
                             srp_userrequest_post_time = srp_userrequest.post_time
@@ -157,14 +168,14 @@ class Command(BaseCommand):
                             srp_userrequest_character = srp_userrequest.character
                             srp_userrequest_srp_link = srp_link
 
-                            srp_userrequest_status = AaSrpRequest.Status.PENDING
+                            srp_userrequest_status = SrpRequest.Status.PENDING
                             if srp_userrequest.srp_status == "Approved":
-                                srp_userrequest_status = AaSrpRequest.Status.APPROVED
+                                srp_userrequest_status = SrpRequest.Status.APPROVED
 
                             if srp_userrequest.srp_status == "Rejected":
-                                srp_userrequest_status = AaSrpRequest.Status.REJECTED
+                                srp_userrequest_status = SrpRequest.Status.REJECTED
 
-                            srp_request = AaSrpRequest()
+                            srp_request = SrpRequest()
                             srp_request.killboard_link = srp_userrequest_killboard_link
                             srp_request.request_status = srp_userrequest_status
                             srp_request.payout_amount = srp_userrequest_payout
@@ -178,13 +189,13 @@ class Command(BaseCommand):
                             srp_request.save()
 
                             # add request info to comments
-                            srp_request_comment = AaSrpRequestComment()
+                            srp_request_comment = RequestComment()
                             srp_request_comment.comment = (
                                 srp_userrequest_additional_info
                             )
                             srp_request_comment.srp_request = srp_request
                             srp_request_comment.comment_type = (
-                                AaSrpRequestComment.Type.REQUEST_INFO
+                                RequestComment.Type.REQUEST_INFO
                             )
                             srp_request_comment.creator = srp_userrequest_creator
                             srp_request_comment.save()
@@ -197,11 +208,16 @@ class Command(BaseCommand):
         self.stdout.write(f"SRP requests migrated: {srp_requests_migrated}")
         self.stdout.write(f"SRP requests skipped: {srp_requests_skipped}")
 
-    def handle(self, *args, **options):
+    def handle(self, *args, **options):  # pylint: disable=unused-argument
         """
         Ask before running ...
+
         :param args:
+        :type args:
         :param options:
+        :type options:
+        :return:
+        :rtype:
         """
 
         self.stdout.write(
