@@ -37,12 +37,14 @@ class TestSentinelUser(TestCase):
     def test_sentinel_user(self):
         """
         Test that we get 'deleted' as username for the sentinel user
+
         :return:
+        :rtype:
         """
 
         sentinel_user = get_sentinel_user()
 
-        self.assertEqual(sentinel_user.username, "deleted")
+        self.assertEqual(first=sentinel_user.username, second="deleted")
 
 
 class TestGetFormattedCharacterName(TestCase):
@@ -67,7 +69,7 @@ class TestGetFormattedCharacterName(TestCase):
             character_id=1002, character_name="Thomas Riker"
         )
 
-        add_character_to_user(cls.user_main_character, cls.alt_character)
+        add_character_to_user(user=cls.user_main_character, character=cls.alt_character)
 
         cls.character_without_profile = create_eve_character(
             character_id=1003, character_name="Christopher Pike"
@@ -75,8 +77,10 @@ class TestGetFormattedCharacterName(TestCase):
 
     def test_should_return_formatted_character_name(self):
         """
-        Test should return formatted character name
+        Test should return a formatted character name
+
         :return:
+        :rtype:
         """
 
         html = get_formatted_character_name(character=self.alt_character)
@@ -87,12 +91,14 @@ class TestGetFormattedCharacterName(TestCase):
             f"</small><br>{self.alt_character.character_name}"
         )
 
-        self.assertEqual(html, expected_html)
+        self.assertEqual(first=html, second=expected_html)
 
     def test_should_return_formatted_character_name_with_copy_icon(self):
         """
-        Test should return formatted character name with copy icon
+        Test should return a formatted character name with copy icon
+
         :return:
+        :rtype:
         """
 
         html = get_formatted_character_name(
@@ -113,12 +119,14 @@ class TestGetFormattedCharacterName(TestCase):
             f"</small><br>{self.alt_character.character_name}{copy_icon}"
         )
 
-        self.assertEqual(html, expected_html)
+        self.assertEqual(first=html, second=expected_html)
 
     def test_should_return_formatted_character_name_with_portrait(self):
         """
-        Test should return formatted character name with portrait
+        Test should return a formatted character name with a portrait
+
         :return:
+        :rtype:
         """
 
         html = get_formatted_character_name(
@@ -140,12 +148,14 @@ class TestGetFormattedCharacterName(TestCase):
             "</span>"
         )
 
-        self.assertEqual(html, expected_html)
+        self.assertEqual(first=html, second=expected_html)
 
     def test_should_return_formatted_character_name_with_portrait_inline(self):
         """
-        Test should return formatted character name with portrait (inline)
+        Test should return a formatted character name with a portrait (inline)
+
         :return:
+        :rtype:
         """
 
         html = get_formatted_character_name(
@@ -167,7 +177,7 @@ class TestGetFormattedCharacterName(TestCase):
             "</span>"
         )
 
-        self.assertEqual(html, expected_html)
+        self.assertEqual(first=html, second=expected_html)
 
 
 class TestGetMainForCharacter(TestCase):
@@ -196,8 +206,10 @@ class TestGetMainForCharacter(TestCase):
             character_id=1004, character_name="Jean Luc Riker"
         )
 
-        add_character_to_user(cls.user_main_character, cls.alt_character)
-        add_character_to_user(cls.user_main_character, cls.alt_character_2)
+        add_character_to_user(user=cls.user_main_character, character=cls.alt_character)
+        add_character_to_user(
+            user=cls.user_main_character, character=cls.alt_character_2
+        )
 
         cls.character_without_profile = create_eve_character(
             character_id=1003, character_name="Christopher Pike"
@@ -205,51 +217,65 @@ class TestGetMainForCharacter(TestCase):
 
     def test_get_main_for_character_returns_none(self):
         """
-        Test if we get `None` as main character
+        Test if we get `None` as the main character
+
         :return:
+        :rtype:
         """
 
-        main_character = get_main_for_character(self.character_without_profile)
+        main_character = get_main_for_character(
+            character=self.character_without_profile
+        )
 
-        self.assertIsNone(main_character)
+        self.assertIsNone(obj=main_character)
 
     def test_get_main_for_character_raises_exception_related_object_does_not_exist(
         self,
     ):
         """
         Test if we get `EveCharacter.userprofile.RelatedObjectDoesNotExist` as exception
+
         :return:
+        :rtype:
         """
 
-        get_main_for_character(self.character_without_profile)
+        get_main_for_character(character=self.character_without_profile)
 
-        self.assertRaises(EveCharacter.userprofile.RelatedObjectDoesNotExist)
+        self.assertRaises(
+            expected_exception=EveCharacter.userprofile.RelatedObjectDoesNotExist
+        )
 
     def test_get_main_for_character_raises_exception_related_object_does_not_exist_2(
         self,
     ):
         """
         Test if we get `CharacterOwnership.user.RelatedObjectDoesNotExist` as exception
+
         :return:
+        :rtype:
         """
 
         self.alt_character_2.character_ownership.user = None
 
-        get_main_for_character(self.alt_character_2)
+        get_main_for_character(character=self.alt_character_2)
 
-        self.assertRaises(CharacterOwnership.user.RelatedObjectDoesNotExist)
+        self.assertRaises(
+            expected_exception=CharacterOwnership.user.RelatedObjectDoesNotExist
+        )
 
     def test_get_main_for_character_returns_main_character(self):
         """
         Test if we get the main character
+
         :return:
+        :rtype:
         """
 
-        main_character = get_main_for_character(self.alt_character)
+        main_character = get_main_for_character(character=self.alt_character)
 
         self.assertEqual(
-            main_character.character_name,
-            self.user_main_character.profile.main_character.character_name,
+            first=main_character.character_name,
+            second=self.user_main_character.profile.main_character.character_name,
         )
 
 
@@ -279,8 +305,10 @@ class TestGetUserForCharacter(TestCase):
             character_id=1004, character_name="Jean Luc Riker"
         )
 
-        add_character_to_user(cls.user_main_character, cls.alt_character)
-        add_character_to_user(cls.user_main_character, cls.alt_character_2)
+        add_character_to_user(user=cls.user_main_character, character=cls.alt_character)
+        add_character_to_user(
+            user=cls.user_main_character, character=cls.alt_character_2
+        )
 
         cls.character_without_profile = create_eve_character(
             character_id=1003, character_name="Christopher Pike"
@@ -289,49 +317,63 @@ class TestGetUserForCharacter(TestCase):
     def test_get_user_for_character_returns_sentinel_user(self):
         """
         Test if we get the sentinel user
+
         :return:
+        :rtype:
         """
 
-        returned_user = get_user_for_character(self.character_without_profile)
+        returned_user = get_user_for_character(character=self.character_without_profile)
         sentinel_user = get_sentinel_user()
 
-        self.assertEqual(returned_user, sentinel_user)
+        self.assertEqual(first=returned_user, second=sentinel_user)
 
     def test_get_user_for_character_raises_exception_related_object_does_not_exist(
         self,
     ):
         """
         Test if we get `EveCharacter.userprofile.RelatedObjectDoesNotExist` as exception
+
         :return:
+        :rtype:
         """
 
-        get_user_for_character(self.character_without_profile)
+        get_user_for_character(character=self.character_without_profile)
 
-        self.assertRaises(EveCharacter.userprofile.RelatedObjectDoesNotExist)
+        self.assertRaises(
+            expected_exception=EveCharacter.userprofile.RelatedObjectDoesNotExist
+        )
 
     def test_get_user_for_character_returns_user(self):
         """
-        Test if we get `User` object
+        Test if we get a `User` object
+
         :return:
+        :rtype:
         """
 
-        returned_user = get_user_for_character(self.alt_character)
+        returned_user = get_user_for_character(character=self.alt_character)
 
-        self.assertEqual(returned_user, self.user_main_character.profile.user)
+        self.assertEqual(
+            first=returned_user, second=self.user_main_character.profile.user
+        )
 
     def test_get_user_for_character_returns_sentinel_user_for_none(self):
         """
         Test if we get the sentinel user when user profile is None
+
         :return:
+        :rtype:
         """
 
         self.alt_character_2.character_ownership.user = None
 
-        returned_user = get_user_for_character(self.alt_character_2)
+        returned_user = get_user_for_character(character=self.alt_character_2)
         expected_user = get_sentinel_user()
 
-        self.assertEqual(returned_user, expected_user)
-        self.assertRaises(CharacterOwnership.user.RelatedObjectDoesNotExist)
+        self.assertEqual(first=returned_user, second=expected_user)
+        self.assertRaises(
+            expected_exception=CharacterOwnership.user.RelatedObjectDoesNotExist
+        )
 
 
 class TestGetMainCharacterFromUser(TestCase):
@@ -359,45 +401,53 @@ class TestGetMainCharacterFromUser(TestCase):
     def test_get_main_character_from_user_should_return_character_name(self):
         """
         Test should return the main character name for a regular user
+
         :return:
+        :rtype:
         """
 
-        character_name = get_main_character_from_user(self.user_main_character)
+        character_name = get_main_character_from_user(user=self.user_main_character)
 
-        self.assertEqual(character_name, "William T. Riker")
+        self.assertEqual(first=character_name, second="William T. Riker")
 
     def test_get_main_character_from_user_should_return_user_name(self):
         """
         Test should return just the username for a user without a character
+
         :return:
+        :rtype:
         """
 
-        user = AuthUtils.create_user("John Doe")
+        user = AuthUtils.create_user(username="John Doe")
 
-        character_name = get_main_character_from_user(user)
+        character_name = get_main_character_from_user(user=user)
 
-        self.assertEqual(character_name, "John Doe")
+        self.assertEqual(first=character_name, second="John Doe")
 
     def test_get_main_character_from_user_should_return_sentinel_user(self):
         """
         Test should return "deleted" as username (Sentinel User)
+
         :return:
+        :rtype:
         """
 
         user = get_sentinel_user()
 
-        character_name = get_main_character_from_user(user)
+        character_name = get_main_character_from_user(user=user)
 
-        self.assertEqual(character_name, "deleted")
+        self.assertEqual(first=character_name, second="deleted")
 
     def test_get_main_character_from_user_should_return_sentinel_user_for_none(self):
         """
         Test should return "deleted" (Sentinel User) if user is None
+
         :return:
+        :rtype:
         """
 
         user = None
 
-        character_name = get_main_character_from_user(user)
+        character_name = get_main_character_from_user(user=user)
 
-        self.assertEqual(character_name, "deleted")
+        self.assertEqual(first=character_name, second="deleted")
