@@ -13,9 +13,11 @@ class TestFleetType(TestCase):
     def test_model_string_names(self):
         """
         Test model string names
+
         :return:
+        :rtype:
         """
 
         topic = create_fleettype(name="Test Fleet Type")
 
-        self.assertEqual(str(topic), "Test Fleet Type")
+        self.assertEqual(first=str(topic), second="Test Fleet Type")
